import math
import os

import arcpy


def has_field(layer, field_name, field_type):
    fields = arcpy.Describe(layer).fields
    field_name = field_name.lower()
    for field in fields:
        if field.name.lower() == field_name:
            return field.type.lower() == field_type.lower()                
    return False


def get_workspace(layer):
    feat_class = arcpy.Describe(layer).featureClass
    dirname = os.path.dirname(feat_class.catalogPath)
    desc = arcpy.Describe(dirname)
    if hasattr(desc, 'datasetType') and desc.datasetType=='FeatureDataset':
        dirname = os.path.dirname(dirname)
    return dirname


def set_progressor(item_count, message):
    """Sets up a geoprocessing step progressor.

    Sets up a geoprocessing step progressor with the desired message and max
    count.  The calling script should use the returned increment in a loop to
    know when to update the progressor, e.g.,

        for i, row in enumerate(cursor):
            if (i % increment) == 0:
                arcpy.SetProgressorPosition(i)
    
    Args:
        item_count: Total number of items to process
        message: Message to display in the progressor

    Returns:
      The increment for updating the progress

    See also:
        https://pro.arcgis.com/en/pro-app/arcpy/geoprocessing_and_python/controlling-the-progress-dialog-box.htm

    """
    # Find a suitable increment
    item_count = int(item_count)
    p = int(math.log10(item_count))
    if not p:
        p = 1
    increment = int(math.pow(10, p - 1))
    
    arcpy.SetProgressor('step', message, 0, item_count, increment)
    return increment
